@@ -14,6 +14,9 @@
 from __future__ import absolute_import, division, print_function
 from __future__ import unicode_literals
 
+import hashlib
+import urllib
+
 
 def url_for(request, endpoint, **values):
     force_external = values.pop("_force_external", False)
@@ -21,3 +24,14 @@ def url_for(request, endpoint, **values):
         endpoint, values,
         force_external=force_external,
     )
+
+
+def gravatar_url(email, size=80):
+    email_hash = hashlib.md5(email.strip().lower()).hexdigest()
+
+    url = "https://secure.gravatar.com/avatar/{}".format(email_hash)
+    params = {
+        "size": size,
+    }
+
+    return "?".join([url, urllib.urlencode(params)])
